All Classes Interface Summary Class Summary Enum Summary Exception Summary
| Class |
Description |
| AbstractBeamCalcRel |
BeamRelNode to replace Project and Filter node.
|
| AggregationCombineFnAdapter<T> |
Wrapper Combine.CombineFns for aggregation function calls.
|
| ArrayAgg |
|
| ArrayAgg.ArrayAggArray<T> |
|
| AvroTableProvider |
|
| BaseBeamTable |
|
| BeamAggregateProjectMergeRule |
This rule is essentially a wrapper around Calcite's AggregateProjectMergeRule.
|
| BeamAggregationRel |
|
| BeamAggregationRule |
Rule to detect the window/trigger settings.
|
| BeamBasicAggregationRule |
Aggregation rule that doesn't include projection.
|
| BeamBigQuerySqlDialect |
|
| BeamBuiltinAggregations |
Built-in aggregations functions for COUNT/MAX/MIN/SUM/AVG/VAR_POP/VAR_SAMP.
|
| BeamBuiltinAggregations.BitXOr<T extends java.lang.Number> |
|
| BeamBuiltinAnalyticFunctions |
Built-in Analytic Functions for the aggregation analytics functionality.
|
| BeamBuiltinAnalyticFunctions.PositionAwareCombineFn<InputT,AccumT,OutputT> |
|
| BeamBuiltinFunctionProvider |
BeamBuiltinFunctionClass interface.
|
| BeamCalciteSchema |
|
| BeamCalciteTable |
|
| BeamCalcMergeRule |
|
| BeamCalcRel |
BeamRelNode to replace Project and Filter node.
|
| BeamCalcRel.WrappedList<T> |
WrappedList translates List on access.
|
| BeamCalcRel.WrappedMap<V> |
WrappedMap translates Map on access.
|
| BeamCalcRel.WrappedRow |
WrappedRow translates Row on access.
|
| BeamCalcRule |
|
| BeamCalcSplittingRule |
|
| BeamCoGBKJoinRel |
A BeamJoinRel which does CoGBK Join
|
| BeamCoGBKJoinRule |
Rule to convert LogicalJoin node to BeamCoGBKJoinRel node.
|
| BeamCostModel |
VolcanoCost represents the cost of a plan node.
|
| BeamCostModel.Factory |
|
| BeamEnumerableConverter |
BeamRelNode to replace a Enumerable node.
|
| BeamEnumerableConverterRule |
A ConverterRule to Convert BeamRelNode to EnumerableConvention.
|
| BeamIntersectRel |
BeamRelNode to replace a Intersect node.
|
| BeamIntersectRule |
ConverterRule to replace Intersect with BeamIntersectRel.
|
| BeamIOPushDownRule |
|
| BeamIOSinkRel |
BeamRelNode to replace a TableModify node.
|
| BeamIOSinkRule |
|
| BeamIOSourceRel |
BeamRelNode to replace a TableScan node.
|
| BeamJavaTypeFactory |
customized data type in Beam.
|
| BeamJoinAssociateRule |
This is very similar to JoinAssociateRule.
|
| BeamJoinPushThroughJoinRule |
This is exactly similar to JoinPushThroughJoinRule.
|
| BeamJoinRel |
An abstract BeamRelNode to implement Join Rels.
|
| BeamJoinTransforms |
Collections of PTransform and DoFn used to perform JOIN operation.
|
| BeamJoinTransforms.JoinAsLookup |
Transform to execute Join as Lookup.
|
| BeamKafkaCSVTable |
A Kafka topic that saves records as CSV format.
|
| BeamKafkaTable |
BeamKafkaTable represent a Kafka topic, as source or target.
|
| BeamLogicalConvention |
Convention for Beam SQL.
|
| BeamMatchRel |
BeamRelNode to replace a Match node.
|
| BeamMatchRule |
ConverterRule to replace Match with BeamMatchRel.
|
| BeamMinusRel |
BeamRelNode to replace a Minus node.
|
| BeamMinusRule |
ConverterRule to replace Minus with BeamMinusRel.
|
| BeamPCollectionTable<InputT> |
BeamPCollectionTable converts a PCollection<Row> as a virtual table, then a
downstream query can query directly.
|
| BeamPushDownIOSourceRel |
|
| BeamRelDataTypeSystem |
customized data type in Beam.
|
| BeamRelMetadataQuery |
|
| BeamRelNode |
A RelNode that can also give a PTransform that implements the expression.
|
| BeamRuleSets |
RuleSet used in BeamQueryPlanner.
|
| BeamSetOperatorRelBase |
Delegate for Set operators: BeamUnionRel, BeamIntersectRel and
BeamMinusRel.
|
| BeamSetOperatorRelBase.OpType |
Set operator type.
|
| BeamSetOperatorsTransforms |
Collections of PTransform and DoFn used to perform Set operations.
|
| BeamSetOperatorsTransforms.BeamSqlRow2KvFn |
Transform a BeamSqlRow to a KV<BeamSqlRow, BeamSqlRow>.
|
| BeamSetOperatorsTransforms.SetOperatorFilteringDoFn |
Filter function used for Set operators.
|
| BeamSideInputJoinRel |
A BeamJoinRel which does sideinput Join
|
| BeamSideInputJoinRule |
Rule to convert LogicalJoin node to BeamSideInputJoinRel node.
|
| BeamSideInputLookupJoinRel |
A BeamJoinRel which does Lookup Join
|
| BeamSideInputLookupJoinRule |
Rule to convert LogicalJoin node to BeamSideInputLookupJoinRel node.
|
| BeamSortRel |
BeamRelNode to replace a Sort node.
|
| BeamSortRel.BeamSqlRowComparator |
|
| BeamSortRule |
ConverterRule to replace Sort with BeamSortRel.
|
| BeamSqlCli |
BeamSqlCli provides methods to execute Beam SQL with an interactive client.
|
| BeamSqlEnv |
Contains the metadata of tables/UDF functions, and exposes APIs to
query/validate/optimize/translate SQL statements.
|
| BeamSqlEnv.BeamSqlEnvBuilder |
BeamSqlEnv's Builder.
|
| BeamSqlOutputToConsoleFn |
A test PTransform to display output in console.
|
| BeamSqlParser |
|
| BeamSqlPipelineOptions |
Options used to configure BeamSQL.
|
| BeamSqlPipelineOptionsRegistrar |
|
| BeamSqlRelUtils |
Utilities for BeamRelNode.
|
| BeamSqlSeekableTable |
A seekable table converts a JOIN operator to an inline lookup.
|
| BeamSqlTable |
This interface defines a Beam Sql Table.
|
| BeamSqlTableFilter |
This interface defines Beam SQL Table Filter.
|
| BeamSqlUdf |
Interface to create a UDF in Beam SQL.
|
| BeamSqlUnparseContext |
|
| BeamSystemDbMetadataSchema |
A Calcite Schema responsible for SHOW DATABASES requests.
|
| BeamSystemSchema |
A Calcite Schema specialized for displaying the session's metadata.
|
| BeamSystemTableMetadataSchema |
A Calcite Schema responsible for SHOW TABLES requests.
|
| BeamTableFunctionScanRel |
BeamRelNode to replace TableFunctionScan.
|
| BeamTableFunctionScanRule |
This is the conveter rule that converts a Calcite TableFunctionScan to Beam
TableFunctionScanRel.
|
| BeamTableStatistics |
This class stores row count statistics.
|
| BeamTableUtils |
Utility methods for working with BeamTable.
|
| BeamUncollectRel |
BeamRelNode to implement an uncorrelated Uncollect, aka UNNEST.
|
| BeamUncollectRule |
|
| BeamUnionRel |
|
| BeamUnionRule |
|
| BeamUnnestRel |
BeamRelNode to implement UNNEST, supporting specifically only Correlate with
Uncollect.
|
| BeamUnnestRule |
|
| BeamValuesRel |
BeamRelNode to replace a Values node.
|
| BeamValuesRule |
ConverterRule to replace Values with BeamValuesRel.
|
| BeamWindowRel |
BeamRelNode to replace a Window node.
|
| BeamWindowRule |
|
| BigDecimalConverter |
Provides converters from BigDecimal to other numeric types based on the input Schema.TypeName.
|
| BigQueryFilter |
|
| BigQueryTableProvider |
BigQuery table provider.
|
| BigtableTable |
|
| BigtableTableProvider |
|
| BuiltinHashFunctions |
Hash Functions.
|
| BuiltinStringFunctions |
BuiltinStringFunctions.
|
| BuiltinTrigonometricFunctions |
TrigonometricFunctions.
|
| CalciteConnectionWrapper |
Abstract wrapper for CalciteConnection to simplify extension.
|
| CalciteFactoryWrapper |
Wrapper for CalciteFactory.
|
| CalciteQueryPlanner |
The core component to handle through a SQL statement, from explain execution plan, to generate a
Beam pipeline.
|
| CalciteQueryPlanner.NonCumulativeCostImpl |
|
| CalciteUtils |
Utility methods for Calcite related operations.
|
| CalciteUtils.TimeWithLocalTzType |
A LogicalType corresponding to TIME_WITH_LOCAL_TIME_ZONE.
|
| CalcRelSplitter |
CalcRelSplitter operates on a Calc with multiple RexCall sub-expressions that
cannot all be implemented by a single concrete RelNode.
|
| CalcRelSplitter.RelType |
Type of relational expression.
|
| Catalog |
Represents a named and configurable container for managing tables.
|
| CatalogManager |
Top-level authority that manages Catalogs.
|
| CatalogManagerSchema |
|
| CatalogRegistrar |
Over-arching registrar to capture available Catalogs.
|
| CatalogSchema |
A Calcite Schema that corresponds to a Catalog.
|
| CEPCall |
A CEPCall instance represents an operation (node) that contains an operator and a list of
operands.
|
| CEPFieldRef |
A CEPFieldRef instance represents a node that points to a specified field in a
Row.
|
| CEPKind |
CEPKind corresponds to Calcite's SqlKind.
|
| CEPLiteral |
CEPLiteral represents a literal node.
|
| CEPMeasure |
The CEPMeasure class represents the Measures clause and contains information about output
columns.
|
| CEPOperation |
CEPOperation is the base class for the evaluation operations defined in the
DEFINE syntax of MATCH_RECOGNIZE.
|
| CEPOperator |
The CEPOperator records the operators (i.e.
|
| CEPPattern |
Core pattern class that stores the definition of a single pattern.
|
| CEPUtils |
Some utility methods for transforming Calcite's constructs into our own Beam constructs (for
serialization purpose).
|
| CountIf |
Returns the count of TRUE values for expression.
|
| CountIf.CountIfFn |
|
| CovarianceFn<T extends java.lang.Number> |
Combine.CombineFn for Covariance on Number types.
|
| Customer |
Describes a customer.
|
| CustomTableResolver |
Interface that table providers can implement if they require custom table name resolution.
|
| DataGeneratorPTransform |
The main PTransform that encapsulates the data generation logic.
|
| DataGeneratorRowFn |
A stateful DoFn that converts a sequence of Longs into structured Rows.
|
| DataGeneratorTable |
Represents a 'datagen' table within a Beam SQL pipeline.
|
| DataGeneratorTableProvider |
The service entry point for the 'datagen' table type.
|
| DataStoreV1TableProvider |
|
| DefaultTableFilter |
|
| EmptyCatalogManager |
|
| FullNameTableProvider |
Base class for table providers that look up table metadata using full table names, instead of
querying it by parts of the name separately.
|
| GenerateSequenceTableProvider |
Sequence generator table provider.
|
| InMemoryCatalog |
|
| InMemoryCatalogManager |
|
| InMemoryCatalogRegistrar |
|
| InMemoryMetaStore |
A MetaStore which stores the meta info in memory.
|
| InMemoryMetaTableProvider |
A InMemoryMetaTableProvider is an abstract TableProvider for in-memory types.
|
| InvalidTableException |
Exception thrown when the request for a table is invalid, such as invalid metadata.
|
| IsInf |
IS_INF(X)
|
| IsNan |
IS_NAN(X)
|
| JavaUdfLoader |
Loads UdfProvider implementations from user-provided jars.
|
| JdbcConnection |
Beam JDBC Connection.
|
| JdbcDriver |
Calcite JDBC driver with Beam defaults.
|
| JoinRelOptRuleCall |
This is a class to catch the built join and check if it is a legal join before passing it to the
actual RelOptRuleCall.
|
| JoinRelOptRuleCall.JoinChecker |
This is a function gets the output relation and checks if it is a legal relational node.
|
| KafkaTableProvider |
Kafka table provider.
|
| LazyAggregateCombineFn<InputT,AccumT,OutputT> |
Combine.CombineFn that wraps an AggregateFn.
|
| MetaStore |
The interface to handle CRUD of BeamSql table metadata.
|
| MongoDbTable |
|
| MongoDbTable.DocumentToRow |
|
| MongoDbTable.RowToDocument |
|
| MongoDbTableProvider |
|
| NFA |
NFA is an implementation of non-deterministic finite automata.
|
| NodeStats |
This is a utility class to represent rowCount, rate and window.
|
| NodeStatsMetadata |
This is a metadata used for row count and rate estimation.
|
| NodeStatsMetadata.Handler |
Handler API.
|
| Order |
Describes an order.
|
| OrderKey |
The OrderKey class stores the information to sort a column.
|
| ParquetTableProvider |
|
| ParseException |
Exception thrown when Beam SQL is unable to parse the statement.
|
| PatternCondition |
PatternCondition stores the function to decide whether a row is a match of a single
pattern.
|
| PayloadSerializerKafkaTable |
|
| ProjectSupport |
|
| PubsubLiteTableProvider |
Pub/Sub Lite table provider.
|
| PubsubTableProvider |
|
| Quantifier |
The Quantifier class is intended for storing the information of the quantifier for a
pattern variable.
|
| QueryPlanner |
An interface that planners should implement to convert sql statement to BeamRelNode or
SqlNode.
|
| QueryPlanner.Factory |
|
| QueryPlanner.QueryParameters |
|
| QueryPlanner.QueryParameters.Kind |
|
| ReadOnlyTableProvider |
A ReadOnlyTableProvider provides in-memory read only set of BeamSqlTable
BeamSqlTables.
|
| RelMdNodeStats |
This is the implementation of NodeStatsMetadata.
|
| ScalarFnReflector |
Reflection-based implementation logic for ScalarFn.
|
| ScalarFunctionImpl |
Beam-customized version from ScalarFunctionImpl , to
address BEAM-5921.
|
| SchemaBaseBeamTable |
|
| SchemaIOTableProviderWrapper |
|
| SerializableRexFieldAccess |
SerializableRexFieldAccess.
|
| SerializableRexInputRef |
SerializableRexInputRef.
|
| SerializableRexNode |
SerializableRexNode.
|
| SerializableRexNode.Builder |
SerializableRexNode.Builder.
|
| SqlCheckConstraint |
Parse tree for UNIQUE, PRIMARY KEY constraints.
|
| SqlColumnDeclaration |
Parse tree for column.
|
| SqlConversionException |
Exception thrown when BeamSQL cannot convert sql to BeamRelNode.
|
| SqlCreateCatalog |
|
| SqlCreateDatabase |
|
| SqlCreateExternalTable |
Parse tree for CREATE EXTERNAL TABLE statement.
|
| SqlCreateFunction |
Parse tree for CREATE FUNCTION statement.
|
| SqlDdlNodes |
Utilities concerning SqlNode for DDL.
|
| SqlDropCatalog |
|
| SqlDropDatabase |
|
| SqlDropTable |
Parse tree for DROP TABLE statement.
|
| SqlSetOptionBeam |
SQL parse tree node to represent SET and RESET statements.
|
| SqlTransform |
|
| SqlUseCatalog |
|
| SqlUseDatabase |
|
| StringAgg |
Combine.CombineFns for aggregating strings or bytes with an optional delimiter (default comma).
|
| StringAgg.StringAggByte |
A Combine.CombineFn that aggregates bytes with a byte array as delimiter.
|
| StringAgg.StringAggString |
A Combine.CombineFn that aggregates strings with a string as delimiter.
|
| SystemTables |
Provides BeamSqlTables that track metadata around catalogs, databases, and tables.
|
| SystemTables.CatalogsMetaTable |
|
| SystemTables.DatabasesMetaTable |
|
| SystemTables.TablesMetaTable |
|
| Table |
Represents the metadata of a BeamSqlTable.
|
| Table.Builder |
|
| TableName |
Represents a parsed table name that is specified in a FROM clause (and other places).
|
| TableNameExtractionUtils |
Helper class to extract table identifiers from the query.
|
| TableProvider |
A TableProvider handles the metadata CRUD of a specified kind of tables.
|
| TableUtils |
|
| TestBoundedTable |
Mocked table for bounded data sources.
|
| TestTable |
Base class for mocked table.
|
| TestTableFilter |
|
| TestTableProvider |
Test in-memory table provider for use in tests.
|
| TestTableProvider.PushDownOptions |
|
| TestTableProvider.TableWithRows |
TableWitRows.
|
| TestTableUtils |
Utility functions for mock classes.
|
| TestUnboundedTable |
A mocked unbounded table.
|
| TextJsonTable |
|
| TextTable |
|
| TextTableProvider |
Text table provider.
|
| TextTableProvider.CsvToRow |
Read-side converter for TextTable with format 'csv'.
|
| TextTableProvider.LinesReadConverter |
Read-side converter for TextTable with format 'lines'.
|
| TextTableProvider.LinesWriteConverter |
Write-side converter for for TextTable with format 'lines'.
|
| TVFSlidingWindowFn |
TVFSlidingWindowFn assigns window based on input row's "window_start" and "window_end"
timestamps.
|
| TVFStreamingUtils |
Provides static constants or utils for TVF streaming.
|
| TypedCombineFnDelegate<InputT,AccumT,OutputT> |
A Combine.CombineFn delegating all relevant calls to given delegate.
|
| UdafImpl<InputT,AccumT,OutputT> |
Implement AggregateFunction to take a Combine.CombineFn as UDAF.
|
| UdfImplReflectiveFunctionBase |
Beam-customized version from ReflectiveFunctionBase, to address BEAM-5921.
|
| UdfImplReflectiveFunctionBase.ParameterListBuilder |
Helps build lists of FunctionParameter.
|
| UdfUdafProvider |
Provider for UDF and UDAF.
|
| VarianceFn<T extends java.lang.Number> |
Combine.CombineFn for Variance on Number types.
|
| ZetaSqlUserDefinedSQLNativeTableValuedFunction |
This is a class to indicate that a TVF is a ZetaSQL SQL native UDTVF.
|