Interface BeamSqlSeekableTable

  • All Superinterfaces:
    java.io.Serializable

    @Experimental
    public interface BeamSqlSeekableTable
    extends java.io.Serializable
    A seekable table converts a JOIN operator to an inline lookup. It's triggered by SELECT * FROM FACT_TABLE JOIN LOOKUP_TABLE ON ....
    • Method Summary

      All Methods Instance Methods Abstract Methods Default Methods 
      Modifier and Type Method Description
      java.util.List<org.apache.beam.sdk.values.Row> seekRow​(org.apache.beam.sdk.values.Row lookupSubRow)
      return a list of Row with given key set.
      default void setUp()
      prepare the instance.
      default void tearDown()
      cleanup resources of the instance.
    • Method Detail

      • setUp

        default void setUp()
        prepare the instance.
      • seekRow

        java.util.List<org.apache.beam.sdk.values.Row> seekRow​(org.apache.beam.sdk.values.Row lookupSubRow)
        return a list of Row with given key set.
      • tearDown

        default void tearDown()
        cleanup resources of the instance.