Class TableNameExtractionUtils
- java.lang.Object
-
- org.apache.beam.sdk.extensions.sql.TableNameExtractionUtils
-
public class TableNameExtractionUtils extends java.lang.ObjectHelper class to extract table identifiers from the query.Supports queries:
... FROM table... ... FROM table1, table2 AS x... ... FROM table1 JOIN (LEFT, INNER, OUTER etc) table2 JOIN table3 ... ... FROM table1 UNION (INTERSECT etc) SELECT ...
-
-
Constructor Summary
Constructors Constructor Description TableNameExtractionUtils()
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static java.util.List<TableName>extractTableNamesFromNode(@Nullable org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.sql.SqlNode node)
-
-
-
Method Detail
-
extractTableNamesFromNode
public static java.util.List<TableName> extractTableNamesFromNode(@Nullable org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.sql.SqlNode node)
-
-