Class UdfImplReflectiveFunctionBase
- java.lang.Object
-
- org.apache.beam.sdk.extensions.sql.impl.UdfImplReflectiveFunctionBase
-
- All Implemented Interfaces:
org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.schema.Function
- Direct Known Subclasses:
ScalarFunctionImpl
public abstract class UdfImplReflectiveFunctionBase extends java.lang.Object implements org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.schema.FunctionBeam-customized version fromReflectiveFunctionBase, to address BEAM-5921.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classUdfImplReflectiveFunctionBase.ParameterListBuilderHelps build lists ofFunctionParameter.
-
Field Summary
Fields Modifier and Type Field Description java.lang.reflect.MethodmethodMethod that implements the function.java.util.List<org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.schema.FunctionParameter>parametersTypes of parameter for the function call.
-
Constructor Summary
Constructors Constructor Description UdfImplReflectiveFunctionBase(java.lang.reflect.Method method)UdfImplReflectiveFunctionBaseconstructor.
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static UdfImplReflectiveFunctionBase.ParameterListBuilderbuilder()Creates a ParameterListBuilder.java.util.List<org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.schema.FunctionParameter>getParameters()Returns the parameters of this function.
-
-
-
Method Detail
-
getParameters
public java.util.List<org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.schema.FunctionParameter> getParameters()
Returns the parameters of this function.- Specified by:
getParametersin interfaceorg.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.schema.Function- Returns:
- Parameters; never null
-
builder
public static UdfImplReflectiveFunctionBase.ParameterListBuilder builder()
Creates a ParameterListBuilder.
-
-