Package org.apache.beam.sdk.extensions.sql.impl
Implementation classes of BeamSql.
-
Interface Summary Interface Description BeamSqlPipelineOptions Options used to configure BeamSQL.QueryPlanner An interface that planners should implement to convert sql statement toBeamRelNodeorSqlNode.QueryPlanner.Factory -
Class Summary Class Description BeamCalciteSchema BeamCalciteTable Adapter fromBeamSqlTableto a calcite Table.BeamSqlEnv Contains the metadata of tables/UDF functions, and exposes APIs to query/validate/optimize/translate SQL statements.BeamSqlEnv.BeamSqlEnvBuilder BeamSqlEnv's Builder.BeamSqlPipelineOptionsRegistrar AutoServiceregistrar forBeamSqlPipelineOptions.BeamSystemDbMetadataSchema A CalciteSchemaresponsible forSHOW DATABASESrequests.BeamSystemSchema A CalciteSchemaspecialized for displaying the session's metadata.BeamSystemTableMetadataSchema A CalciteSchemaresponsible forSHOW TABLESrequests.BeamTableStatistics This class stores row count statistics.CalciteConnectionWrapper Abstract wrapper forCalciteConnectionto simplify extension.CalciteFactoryWrapper Wrapper forCalciteFactory.CalciteQueryPlanner The core component to handle through a SQL statement, from explain execution plan, to generate a Beam pipeline.CalciteQueryPlanner.NonCumulativeCostImpl CatalogManagerSchema A CalciteSchemathat corresponds to aCatalogManager.CatalogSchema A CalciteSchemathat corresponds to aCatalog.JavaUdfLoader LoadsUdfProviderimplementations from user-provided jars.JdbcConnection Beam JDBC Connection.JdbcDriver Calcite JDBC driver with Beam defaults.LazyAggregateCombineFn<InputT,AccumT,OutputT> Combine.CombineFnthat wraps anAggregateFn.QueryPlanner.QueryParameters ScalarFnReflector Reflection-based implementation logic forScalarFn.ScalarFunctionImpl Beam-customized version fromScalarFunctionImpl, to address BEAM-5921.TableName Represents a parsed table name that is specified in a FROM clause (and other places).TVFSlidingWindowFn TVFSlidingWindowFn assigns window based on input row's "window_start" and "window_end" timestamps.UdafImpl<InputT,AccumT,OutputT> ImplementAggregateFunctionto take aCombine.CombineFnas UDAF.UdfImplReflectiveFunctionBase Beam-customized version fromReflectiveFunctionBase, to address BEAM-5921.UdfImplReflectiveFunctionBase.ParameterListBuilder Helps build lists ofFunctionParameter.ZetaSqlUserDefinedSQLNativeTableValuedFunction This is a class to indicate that a TVF is a ZetaSQL SQL native UDTVF. -
Enum Summary Enum Description QueryPlanner.QueryParameters.Kind -
Exception Summary Exception Description ParseException Exception thrown when Beam SQL is unable to parse the statement.SqlConversionException Exception thrown when BeamSQL cannot convert sql to BeamRelNode.