Class BaseBeamTable

    • Constructor Summary

      Constructors 
      Constructor Description
      BaseBeamTable()  
    • Method Summary

      All Methods Instance Methods Concrete Methods 
      Modifier and Type Method Description
      org.apache.beam.sdk.values.PCollection<org.apache.beam.sdk.values.Row> buildIOReader​(org.apache.beam.sdk.values.PBegin begin, BeamSqlTableFilter filters, java.util.List<java.lang.String> fieldNames)
      create a PCollection<Row> from source with predicate and/or project pushed-down.
      BeamSqlTableFilter constructFilter​(java.util.List<org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.rex.RexNode> filter)
      Generate an IO implementation of BeamSqlTableFilter for predicate push-down.
      BeamTableStatistics getTableStatistics​(org.apache.beam.sdk.options.PipelineOptions options)
      Estimates the number of rows or the rate for unbounded Tables.
      ProjectSupport supportsProjects()
      Whether project push-down is supported by the IO API.
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

      • BaseBeamTable

        public BaseBeamTable()
    • Method Detail

      • getTableStatistics

        public BeamTableStatistics getTableStatistics​(org.apache.beam.sdk.options.PipelineOptions options)
        Description copied from interface: BeamSqlTable
        Estimates the number of rows or the rate for unbounded Tables. If it is not possible to estimate the row count or rate it will return BeamTableStatistics.BOUNDED_UNKNOWN.
        Specified by:
        getTableStatistics in interface BeamSqlTable
      • buildIOReader

        public org.apache.beam.sdk.values.PCollection<org.apache.beam.sdk.values.Row> buildIOReader​(org.apache.beam.sdk.values.PBegin begin,
                                                                                                    BeamSqlTableFilter filters,
                                                                                                    java.util.List<java.lang.String> fieldNames)
        Description copied from interface: BeamSqlTable
        create a PCollection<Row> from source with predicate and/or project pushed-down.
        Specified by:
        buildIOReader in interface BeamSqlTable
      • constructFilter

        public BeamSqlTableFilter constructFilter​(java.util.List<org.apache.beam.vendor.calcite.v1_40_0.org.apache.calcite.rex.RexNode> filter)
        Description copied from interface: BeamSqlTable
        Generate an IO implementation of BeamSqlTableFilter for predicate push-down.
        Specified by:
        constructFilter in interface BeamSqlTable