Class SchemaBaseBeamTable
- java.lang.Object
-
- org.apache.beam.sdk.extensions.sql.meta.BaseBeamTable
-
- org.apache.beam.sdk.extensions.sql.meta.SchemaBaseBeamTable
-
- All Implemented Interfaces:
java.io.Serializable,BeamSqlTable
- Direct Known Subclasses:
BeamKafkaTable,BeamPCollectionTable,BigtableTable,DataGeneratorTable,MongoDbTable,TestTable,TextTable
public abstract class SchemaBaseBeamTable extends BaseBeamTable implements java.io.Serializable
Each IO in Beam has one table schema, by extendingSchemaBaseBeamTable.- See Also:
- Serialized Form
-
-
Field Summary
Fields Modifier and Type Field Description protected org.apache.beam.sdk.schemas.Schemaschema
-
Constructor Summary
Constructors Constructor Description SchemaBaseBeamTable(org.apache.beam.sdk.schemas.Schema schema)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description org.apache.beam.sdk.schemas.SchemagetSchema()Get the schema info of the table.-
Methods inherited from class org.apache.beam.sdk.extensions.sql.meta.BaseBeamTable
buildIOReader, constructFilter, getTableStatistics, supportsProjects
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.apache.beam.sdk.extensions.sql.meta.BeamSqlTable
buildIOReader, buildIOWriter, isBounded
-
-
-
-
Method Detail
-
getSchema
public org.apache.beam.sdk.schemas.Schema getSchema()
Description copied from interface:BeamSqlTableGet the schema info of the table.- Specified by:
getSchemain interfaceBeamSqlTable
-
-