Class SystemTables
- java.lang.Object
-
- org.apache.beam.sdk.extensions.sql.meta.SystemTables
-
public class SystemTables extends java.lang.ObjectProvidesBeamSqlTables that track metadata around catalogs, databases, and tables. For now, it tracks the following:- Catalogs: Name and Type
- Databases: Name
- Tables: Name and Type
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSystemTables.CatalogsMetaTablestatic classSystemTables.DatabasesMetaTablestatic classSystemTables.TablesMetaTable
-
Constructor Summary
Constructors Constructor Description SystemTables()
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static SystemTables.CatalogsMetaTablecatalogs(CatalogManager catalogManager, boolean currentOnly)static SystemTables.DatabasesMetaTabledatabases(Catalog catalog, boolean currentOnly)static SystemTables.TablesMetaTabletables(Catalog catalog, java.lang.String dbName)
-
-
-
Method Detail
-
catalogs
public static SystemTables.CatalogsMetaTable catalogs(CatalogManager catalogManager, boolean currentOnly)
-
databases
public static SystemTables.DatabasesMetaTable databases(Catalog catalog, boolean currentOnly)
-
tables
public static SystemTables.TablesMetaTable tables(Catalog catalog, java.lang.String dbName)
-
-